@@ -66,12 +66,12 @@ class objective_cnn(object):
         momentum = trial.suggest_float('momentum', 0, 1, step=0.1)
         decay = trial.suggest_float('decay', 0, 0.1, step=0.001)
         nesterov = trial.suggest_categorical('nesterov', [True, False])
-        loss = trial.suggest_categorical('loss', ['categorical_crossentropy', 'squared_hinge', 'sparse_categorical_crossentropy'])
+        loss = trial.suggest_categorical('loss', ['categorical_crossentropy', 'squared_hinge'])
         padding = trial.suggest_categorical('padding', ['same', 'valid'])
         dropout_1 = trial.suggest_float('dropout_1', 0, 1, step=0.1)
         dropout_2 = trial.suggest_float('dropout_2', 0, 1, step=0.1)
-        activation_conv = trial.suggest_categorical('activation_conv', ['relu', 'linear', 'softmax', 'sigmoid', 'tanh', 'softplus'])
-        activation_dense = trial.suggest_categorical('activation_dense', ['relu', 'softmax', 'sigmoid', 'tanh', 'softplus'])
+        activation_conv = trial.suggest_categorical('activation_conv', ['relu',  'sigmoid', 'tanh'])
+        activation_dense = trial.suggest_categorical('activation_dense', ['relu', 'sigmoid', 'tanh'])
         maxpool_size = trial.suggest_int('maxpool_size', 1, 10)
         maxpool_stride = trial.suggest_int('maxpool_stride', 1, 10)
         
